module.exports = defineTest({
	description: 'throw an error when accessing members of null or undefined'
});
